#ifndef _SHARED_H
#define _SHARED_H
#include <cyc_a.h>
#include <upc.h>
shared int blar;
#endif
